@@ -313,6 +313,8 @@ str_append_modified(to, string, length, type)
             type &= ~(REPL_LOWERCASE_FIRST | REPL_UPPERCASE_FIRST);
 	    if (type == REPL_ASIS)
 	      {
+		n = WCRTOMB (to->active + to->length, wc, &to->mbstate);
+		to->length += n;
 		str_append(to, string, length);
 	        return;
 	      }
@@ -324,7 +326,7 @@ str_append_modified(to, string, length, type)
           wc = towlower(wc);
 
 	/* Copy the new wide character to the end of the string. */
-	n = wcrtomb (to->active + to->length, wc, &to->mbstate);
+	n = WCRTOMB (to->active + to->length, wc, &to->mbstate);
         to->length += n;
 	if (n == -1)
 	  {
@@ -1070,7 +1072,6 @@ do_subst(sub)
   countT count = 0;	/* number of matches found */
   bool again = true;
 
-#define MAX_BACKREFERENCES 10
   static struct re_registers regs;
 
   if (s_accum.alloc == 0)
@@ -1080,7 +1081,7 @@ do_subst(sub)
   /* The first part of the loop optimizes s/xxx// when xxx is at the
      start, and s/xxx$// */
   if (!match_regex(sub->regx, line.active, line.length, start,
-		   &regs, MAX_BACKREFERENCES))
+		   &regs, sub->max_id + 1))
     return;
   
   if (!sub->replacement && sub->numb <= 1)
@@ -1158,7 +1159,7 @@ do_subst(sub)
   while (again
 	 && start <= line.length
 	 && match_regex(sub->regx, line.active, line.length, start,
-			&regs, MAX_BACKREFERENCES));
+			&regs, sub->max_id + 1));
 
   /* Copy stuff to the right of the last match into the output string. */
   if (start < line.length)
